# encoding: utf-8
from __future__ import unicode_literals
from __future__ import absolute_import

from spyne.model.complex import Array, ComplexModel
from spyne.model.primitive import (
    Boolean,
    Date,
    DateTime,
    Integer,
    String,
    Unicode,
)

from ..types import Address


class Parent(ComplexModel):
    __type_name__ = 'parent'

    _type_info = [
        ('parentID', Integer),
        ('parentSNILS', Boolean),
        ('addressResid', Address),
        ('addressStay', Address),
        ('addressFact', Address),
    ]

    class Annotations(ComplexModel.Annotations):
        doc = 'Контейнер, содержащий информацию о родителе ребенка.'


class Declaration(ComplexModel):
    __type_name__ = 'declaration'

    _type_info = [
        ('id', Integer),
        ('identificator', String),
        ('childrenID', Integer),
        ('creationDate', DateTime),
        ('changeDate', DateTime),
        ('sourceID', Integer),
        ('birthdate', Date),
        ('prefDate', Date),
        ('firstID', Integer),
        ('secondID', Integer),
        ('thirdID', Integer),
        ('privID', Integer),
        ('shottermGroup', Boolean),
        ('douChange', Boolean),
        ('currentID', Integer.customize(
            min_occurs=1, max_occurs=1, nullable=True)),
        ('addressResid', Address),
        ('addressStay', Address),
        ('addressFact', Address),
        ('parents', Array(Parent)),
        ('childSNILS', Boolean),
        ('healthGroup', Integer),
        ('healthProblem', Integer),
    ]

    class Annotations(ComplexModel.Annotations):
        doc = 'Контейнер, содержащий информацию о заявлении.'


class Declarations(ComplexModel):
    declaration = Array(Declaration)


class Root(ComplexModel):
    __type_name__ = 'AppData'

    declarations = Array(Declaration)
