# encoding: utf-8
from __future__ import absolute_import
from __future__ import unicode_literals

from django.db.models import Q
from lxml.etree import tostring
from spyne.util.xml import get_object_as_xml

from kinder.core.direct.models import DirectStatusLog, Direct

from .types import Root, Direction


def get_content(ctx, report_code, decl_date):
    """Точка входа метода, возвращает строку xml."""

    # Выбираем id направлений созданных или с измененным статусом
    # При создании нового направления создается запись в DirectStatusLog
    # поэтому используется только эта модель
    direct_ids = DirectStatusLog.objects.filter(
        created_at__year=decl_date.year,
        created_at__month=decl_date.month,
        created_at__day=decl_date.day,
    ).values_list('direct_id', flat=True)

    directs = Direct.objects.filter(
        Q(id__in=direct_ids) |
        Q(
            date__year=decl_date.year,
            date__month=decl_date.month,
            date__day=decl_date.day
        )
    ).values(
        'id',
        'declaration_id',
        'status_id',
        'date',
        'group_id',
        'temporary',
        'manual_create',
    )

    directions = []
    for d in directs:
        directions.append(Direction(
            id=d['id'],
            directDate=d['date'],
            declarationID=d['declaration_id'],
            groupID=d['group_id'],
            statusID=d['status_id'],
            temporary=d['temporary'],
            manual=d['manual_create'],
        ))

    root = Root(directions=directions)
    result = tostring(
        get_object_as_xml(root), pretty_print=True, encoding='UTF-8')
    return result
